#!/usr/bin/env python3
# -*- coding: UTF-8 -*-
#
# Author : Eliovir
# Creation Date : 2013-03-17 13:40:49CEST
# Last Revision : $Date: $
# Revision : $Rev: $
"""
Generator of .desktop files, for Elatom.
"""
__revision__ = "$Rev: $"
__author__ = "Eliovir"

import gettext
import configparser
import glob
import locale
import os
import sys

###########
#         #
# Gettext #
#         #
###########
def set_locale(current_locale=None):
    if current_locale is None:
        current_locale, encoding = locale.getdefaultlocale()
    # Hack to get the locale directory
    basepath = os.path.abspath(os.path.dirname(sys.argv[0]))
    localedir = os.path.join(basepath, "locale")
    domain = "elatom"             # the translation file is elatom.mo

    # Set up Python's gettext
    if current_locale != None:
        mytranslation = gettext.translation(domain, localedir,
                                    [current_locale], fallback=True)
        mytranslation.install()
        n_ = mytranslation.ngettext
    else:
        print("Can not setup gettext for %s. Exiting." % locale)
        sys.exit(1)

class Desktop:
    _path = None
    _inifile = None
    _section = "Desktop Entry"

    def __init__(self, path):
        self._inifile = configparser.ConfigParser()
        self._inifile.optionxform = str
        self._path = path
        if os.path.exists(self._path):
            file_handler = open(self._path, 'r+', encoding='utf-8')
            self._inifile.readfp(file_handler)
        if not self._inifile.has_section(self._section):
            self._inifile.add_section(self._section)

    def generate(self, locales):
        """
        Set the content of the .desktop file.
        
        @type   locales:   list
        @param  locales:   locale identifiers
        """
        working_dir = os.path.realpath(os.path.dirname(sys.argv[0]))
        values = {
                # http://www.freedesktop.org/wiki/Specifications/menu-spec
                "Categories": "Network;FileTransfer;Feed;",
                "Comment": "Download automatically your podcasts",
                "Exec": os.path.join(working_dir, "elatom.py"),
                "GenericName": "Podcasts downloader",
                "Hidden": "false",
                "Icon": "elatom",
                "MimeType": "application/rss+xml;application/atom+xml",
                "Name": "Elatom",
                "NoDisplay": "false",
                "StartupNotify": "false",
                "Terminal": "false",
                "Type": "Application",
                "Version": "1.0"
                }

        for locale in locales:
            set_locale(locale)
            # TRANSLATORS: Value of "Comment" in the freedesktop.org .desktop file.
            translated_comment = _("Download automatically your podcasts")
            if not translated_comment == values["Comment"]:
                values["Comment[" + locale + "]"] = translated_comment

            # TRANSLATORS: Value of "GenericName" in the freedesktop.org .desktop file.
            translated_genericname = _("Podcasts downloader")
            if not translated_genericname == values["GenericName"]:
                values["GenericName[" + locale + "]"] = translated_genericname

        keys = list(values.keys())
        keys.sort()
        for key in keys:
            self._inifile.set(self._section, key, values[key])

    def save(self):
        """
        Save the .desktop file.
        """
        with open(self._path, 'w', encoding='utf-8') as inifile:
            self._inifile.write(inifile, space_around_delimiters=False)

if __name__ == "__main__":
    set_locale()
    d = Desktop('elatom.desktop')
    locales = [os.path.basename(fi)[:-3]
                                for fi in glob.glob('locale/*.po')]
    d.generate(locales)
    d.save()
